==> python-pymeasure_0.5.orig.tar.gz: PyMeasure-0.5/pymeasure/instruments/__init__.py <==
#
# This file is part of the PyMeasure package.
#
# Copyright (c) 2013-2017 PyMeasure Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

from ..errors import RangeError, RangeException
from .instrument import Instrument
from .mock import Mock
from .resources import list_resources
from .validators import discreteTruncate

from . import agilent
from . import anritsu
from . import danfysik
from . import fwbell
from . import hp
from . import keithley
from . import lakeshore
from . import parker
from . import signalrecovery
from . import srs
from . import tektronix
from . import thorlabs
from . import yokogawa

==> python-pymeasure_0.9.0.orig.tar.gz: PyMeasure-0.9.0/pymeasure/instruments/__init__.py <==
#
# This file is part of the PyMeasure package.
#
# Copyright (c) 2013-2021 PyMeasure Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

from ..errors import RangeError, RangeException
from .instrument import Instrument
from .mock import Mock
from .resources import list_resources
from .validators import discreteTruncate

from . import advantest
from . import agilent
from . import ametek
from . import ami
from . import anapico
from . import anritsu
from . import attocube
from . import danfysik
from . import deltaelektronika
from . import fwbell
from . import hp
from . import keithley
from . import keysight
from . import lakeshore
from . import newport
from . import ni
from . import oxfordinstruments
from . import parker
from . import razorbill
from . import signalrecovery
from . import srs
from . import tektronix
from . import thorlabs
from . import yokogawa
